import {Component, OnInit, ViewChild} from '@angular/core';
import {FormBuilder, FormControl, FormGroup, Validators} from '@angular/forms';
import {WorkService} from '../../work.service';
import {NzMessageService, UploadFile} from 'ng-zorro-antd';
import {SelectPersonComponent} from '../../../modal/select-person/select-person.component';

@Component({
    selector: 'smart-event',
    templateUrl: './event.component.html',
    styles: []
})
export class EventComponent implements OnInit {
    @ViewChild('smartSelectPerson') smartSelectPerson:SelectPersonComponent;

    isVisible = false;
    title;
    eventId;
    validateForm: FormGroup;

    fileList: UploadFile[] = [];
    operatorsList = [];    //处理人列表
    constructor(private workSer: WorkService, private message: NzMessageService,
                private fb: FormBuilder) {
    }

    ngOnInit() {}

    initForm() {
        this.validateForm = this.fb.group(
            {
                title: [null, [Validators.required]],
                description: [null],
                type: [null],
                requester: [null],
                file: [null],
                requesterPhone: [null],
                operators: [null],
            }
        );
    }

    beforeUpload = (file: UploadFile): boolean => {
        const isLt5M = file.size / 1024 < 5000;
        if (!isLt5M) {
            this.message.error('图标必须小于5M!');
        } else {
            this.fileList.push(file);
        }
        return false;
    };

    showAddModal(title) {
        this.isVisible = true;
        this.title = title;
    }

    showEditModal(title, id) {
        this.isVisible = true;
        this.title = title;
        this.eventId = id;
    }

    handEditleOk() {
        if (this.title == '新增事件') {
            this.create();
        }
        if (this.title == '编辑事件') {
            this.update();
        }
    }

    //新增
    create() {
        let formData = new FormData();
        this.fileList.forEach((file: any) => {
            formData.append('file', file);
        });
        formData.append('json', JSON.stringify(this.validateForm.value));
        this.workSer.create(formData).subscribe(
            (res) => {
                if (res.errCode == 10000) {
                    this.message.success('新增事件成功');
                } else {
                    this.message.error(res.errMsg);
                }
            }
        );
    }

    //编辑
    update() {
        let formData = new FormData();
        this.fileList.forEach((file: any) => {
            formData.append('file', file);
        });
        formData.append('json', JSON.stringify(this.validateForm.value));
        formData.append('id', this.eventId);
        this.workSer.update(formData).subscribe(
            (res) => {
                if (res.errCode == 10000) {
                    this.message.success('修改事件成功');
                } else {
                    this.message.error(res.errMsg);
                }
            }
        );
    }

    handleEditCancel() {
        this.isVisible = false;
    }

    //选择处理人
    selectPerson(){
        // this.smartSelectPerson.showModal("选择处理人");
    }

    deletePerson(i){
        this.operatorsList.splice(i,1);
    }

    getUser(e) {
        const arr = [];
        e.forEach(res => {
            const data = {
                username: res.name,
                userId: res.id
            };
            arr.push(data);
        });
        this.operatorsList = arr;
    }
}
